@@ -1,27 +1,19 @@
-# PMML: Predictive Modelling Markup Language
+# PMML: Predictive Model Markup Language
 #
-# Part of the Rattle package for Data Mining
+# Copyright (c) 2009-2013, some parts by Togaware Pty Ltd and other by Zementis, Inc. 
 #
-# Handle coxph regression model.
+# This file is part of the PMML package for R.
 #
-# Time-stamp: <2012-12-04 06:06:58 Graham Williams>
+# The PMML package is free software: you can redistribute it and/or 
+# modify it under the terms of the GNU General Public License as
+# published by the Free Software Foundation, either version 2 of 
+# the License, or (at your option) any later version.
 #
-# Copyright (c) 2009 Togaware Pty Ltd
-#
-# This files is part of the Rattle suite for Data Mining in R.
-#
-# Rattle is free software: you can redistribute it and/or modify it
-# under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 2 of the License, or
-# (at your option) any later version.
-#
-# Rattle is distributed in the hope that it will be useful, but
-# WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-# General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with Rattle. If not, see <http://www.gnu.org/licenses/>.
+# The PMML package is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. Please see the
+# GNU General Public License for details (http://www.gnu.org/licenses/).
+######################################################################################
 
 ########################################################################
 # Linear Model PMML exporter
@@ -37,8 +29,6 @@ pmml.coxph <- function(model,
                        ...)
 {
   if (! inherits(model, "coxph")) stop("Not a legitimate coxph object")
-  
-  #require(XML, quietly=TRUE)
 
   # Collect the required information.
 
@@ -142,11 +132,6 @@ pmml.coxph <- function(model,
   orig.names <- field$name
   orig.class <- field$class
 
-  if (.supportTransformExport(transforms))
-  {
-    field <- .unifyTransforms(field, transforms)
-    transforms <- .activateDependTransforms(transforms)
-  }
   number.of.fields <- length(field$name)
 
   target <- field$name[1]
@@ -305,7 +290,7 @@ pmml.coxph <- function(model,
 
   # PMML -> RegressionModel -> MiningSchema
 
-  the.model <- append.XMLNode(the.model, .pmmlMiningSchema(field2, target, inactive, transforms))
+  the.model <- append.XMLNode(the.model, .pmmlMiningSchema(field2, target, transforms))
 
   # Tridi Zementis: Add output fields to output both hazard and survival
 
@@ -330,13 +315,14 @@ pmml.coxph <- function(model,
  
   # PMML -> TreeModel -> LocalTransforms
 
-  if (.supportTransformExport(transforms))
-    the.model <- append.XMLNode(the.model, .gen.transforms(transforms))
+# Wen ... commented to see if it break anything ... august 2013
+#  if (.supportTransformExport(transforms))
+#    the.model <- append.XMLNode(the.model, .gen.transforms(transforms))
 
   # test of Zementis xform functions
   if(!is.null(transforms))
   {
-    the.model <- append.XMLNode(the.model, pmmlLocalTransformations(field, transforms))
+    the.model <- append.XMLNode(the.model, .pmmlLocalTransformations(field, transforms))
   }
 
  plNode <- xmlNode("ParameterList")
